LogSeverity enum

Inheritance
Implemented types
Available extensions

Values

defaultSeverity → const LogSeverity
const LogSeverity._(0, 'DEFAULT')
debug → const LogSeverity
const LogSeverity._(100, 'DEBUG')
info → const LogSeverity
const LogSeverity._(200, 'INFO')
notice → const LogSeverity
const LogSeverity._(300, 'NOTICE')
warning → const LogSeverity
const LogSeverity._(400, 'WARNING')
error → const LogSeverity
const LogSeverity._(500, 'ERROR')
critical → const LogSeverity
const LogSeverity._(600, 'CRITICAL')
alert → const LogSeverity
const LogSeverity._(700, 'ALERT')
emergency → const LogSeverity
const LogSeverity._(800, 'EMERGENCY')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

compareTo(LogSeverity other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<LogSeverity>
A constant List of the values in this enum, in order of their declaration.